@@ -1,6 +1,6 @@
 
 /* 
- * Copyright (c) 1998,99,2000,2001,2002,2003,2004,2006 David Stes
+ * Copyright (c) 1998,99,2000,01,02,03,04,06,08,09 David Stes
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Library General Public License as published 
@@ -17,8 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#define OBJCVERSION "3.2.8"
-#define OBJC1VERSION "objc3.2.8"
+#define OBJCVERSION "3.2.9"
+#define OBJC1VERSION "objc3.2.9"
 
 #include <string.h>		/* strtok */
 #include <stdlib.h>		/* getenv */
@@ -45,7 +45,7 @@ void printversion(void)
 
 void printcopyright(void)
 {
-  printf("Portable Object Compiler %s (c) 1997, 98, 99, 2000, 01, 02, 03, 04.\n",OBJCVERSION);
+  printf("Portable Object Compiler %s (c) 1997,98,99,2000,01,02,03,04,08,09.\n",OBJCVERSION);
   printf("Distributed under the terms of the GNU LGPL.\n");
 }
 
@@ -470,7 +470,7 @@ void setfirstlinetag(void)
     definebuiltinfun("__builtin_strncmp");
 
     /* the following are not really gnu, they're SUN headers */
-    definebuiltinfun("__builtin_va_alist");
+    definebuiltinvar("__builtin_va_alist");
     definebuiltinfun("__builtin_va_arg_incr");
   }
 }
