@@ -1,7 +1,7 @@
 
 /*
- * Portable Object Compiler (c) 1997,98,99,00,01,02.  All Rights Reserved.
- * $Id: objcrt.m,v 1.5 2002/03/29 09:04:26 stes Exp $
+ * Portable Object Compiler (c) 1997,98,99,00,01,04.  All Rights Reserved.
+ * $Id: objcrt.m,v 1.8 2004/07/24 18:50:39 stes Exp $
  */
 
 /*
@@ -28,6 +28,8 @@
 #endif
 
 #include "Block.h"		/* blockRaise */
+#include "Exceptn.h"		/* signal exceptions */
+#include "OutOfMem.h"		/* signal exceptions */
 #include "Message.h"		/* selector:args: */
 #include <assert.h>
 #include <stdlib.h>
@@ -222,7 +224,7 @@ freemodnode (modnode_t * n, modnode_t m)
  *
  ****************************************************************************/
 
-id OC_Malloc_msg;		/* must be allocated before error happens */
+static id outOfMem;		/* must be allocated before error happens */
 
 void EXPORT *
 OC_Malloc (size_t nBytes)
@@ -235,22 +237,15 @@ OC_Malloc (size_t nBytes)
   if (nBytes > 32 * 1024)
     dbg ("OC_Malloc call for %i bytes\n", nBytes);
 
-  while (1)
-    {
-
 #if OBJCRT_BOEHM
-      data = GC_malloc (nBytes);
+  data = GC_malloc (nBytes);
 #else
-      data = malloc (nBytes);
+  data = malloc (nBytes);
 #endif
 
-      /* try until the handler aborts or frees memory */
-      if (!data)
-	[Object halt:OC_Malloc_msg];
-      else
-	break;
-    }
-
+  /* signal the OutOfMemory exception */
+  if (!data)
+    [outOfMem signal];
   return data;
 }
 
@@ -264,22 +259,15 @@ OC_MallocAtomic (size_t nBytes)
   if (nBytes > 32 * 1024)
     dbg ("OC_MallocAtomic call for %i bytes\n", nBytes);
 
-  while (1)
-    {
-
 #if OBJCRT_BOEHM
-      data = GC_malloc_atomic (nBytes);
+  data = GC_malloc_atomic (nBytes);
 #else
-      data = malloc (nBytes);
+  data = malloc (nBytes);
 #endif
 
-      /* try until the handler aborts or frees memory */
-      if (!data)
-	[Object halt:OC_Malloc_msg];
-      else
-	break;
-    }
-
+  /* signal the OutOfMemory exception */
+  if (!data)
+    [outOfMem signal];
   return data;
 }
 
@@ -304,25 +292,15 @@ OC_Realloc (void *data, size_t nBytes)
   if (nBytes > 32 * 1024)
     dbg ("OC_Realloc call for %i bytes\n", nBytes);
 
-  if (!data)
-    [Object halt:OC_Malloc_msg];
-
-  while (1)
-    {
-
 #if OBJCRT_BOEHM
-      data = GC_realloc (data, nBytes);
+  data = GC_realloc (data, nBytes);
 #else
-      data = realloc (data, nBytes);
+  data = realloc (data, nBytes);
 #endif
 
-      /* try until the handler aborts or frees memory */
-      if (!data)
-	[Object halt:OC_Malloc_msg];
-      else
-	break;
-    }
-
+  /* signal the OutOfMemory exception */
+  if (!data)
+    [outOfMem signal];
   return data;
 }
 
@@ -726,7 +704,7 @@ id EXPORT
 __showOn (id self, unsigned level /* unused */ )
 {
   (*_fileOut) (stderr, self);
-  return self;
+  return nil;
 }
 
 id (*_showOn) (id, unsigned) = __showOn;
@@ -804,25 +782,13 @@ static PHASH
 hashNew (STR key, PHASH link)
 {
   int n;
-  PHASH obj = (PHASH) OC_Malloc (sizeof (HASH));
+  PHASH obj;
   assert (key != NULL);
+  obj = (PHASH) OC_Malloc (sizeof (HASH));
   obj->next = link;
   n = strlen (key);
   obj->key = (STR) OC_Malloc (n + 1);
   strcpy (obj->key, key);
-  key = obj->key;
-  if (minsel)
-    {
-      if (key < minsel)
-	minsel = key;
-      if (key > maxsel)
-	maxsel = key;
-    }
-  else
-    {
-      minsel = key;
-      maxsel = key;
-    }
   return obj;
 }
 
@@ -848,6 +814,18 @@ static PHASH
 hashEnter (STR key, int slot)
 {
   assert (key != NULL);
+  if (minsel)
+    {
+      if (key < minsel)
+	minsel = key;
+      if (key > maxsel)
+	maxsel = key;
+    }
+  else
+    {
+      minsel = key;
+      maxsel = key;
+    }
   if (slot < 0)
     slot = strHash (key) % nHashLists;
   hashList [slot] = hashNew (key, hashList [slot]);
@@ -1264,9 +1242,7 @@ _objcInitNoShared (
          * This must be done after initializing the runtime
        */
 
-      OC_Malloc_msg = [Object findClass:"String"];
-      if (OC_Malloc_msg)
-	OC_Malloc_msg = [OC_Malloc_msg str:"Out of memory."];
+      outOfMem = [OutOfMemory new];
 
       /* finished _objcInit(). it's now safe for loadobjc() to
        * call initobjc()
